@@ -288,6 +288,9 @@ def _addConstantInitCode(context, emit, check, constant_type, constant_value,
     if constant_identifier in done:
         return
 
+    if Options.shallTraceExecution():
+        emit("""puts("Creating constant: %s");""" % constant_identifier)
+
     # Then it's a real named constant not yet created.
     __addConstantInitCode(context, emit, check, constant_type, constant_value,
                           constant_identifier, module_level)
@@ -369,7 +372,7 @@ def __addConstantInitCode(context, emit, check, constant_type, constant_value,
                 """\
 %s = PyLong_FromLong( %sl ); // To be corrected with -1 in-place next lines.
 CHECK_OBJECT( const_int_pos_1 );
-%s = PyNumber_InPlaceSubtract( %s, const_int_pos_1 );""" % (
+%s = PyNumber_InPlaceSubtract( %s, PyLong_FromLong( 1 ) );""" % (
                     constant_identifier,
                     min_signed_long,
                     constant_identifier,
@@ -401,7 +404,7 @@ CHECK_OBJECT( const_int_pos_1 );
             emit(
                 """\
 %s = PyInt_FromLong( %sl );  // To be corrected in next line.
-%s = PyNumber_InPlaceSubtract( %s, const_int_pos_1 );""" % (
+%s = PyNumber_InPlaceSubtract( %s, PyInt_FromLong( 1 ) );""" % (
                     constant_identifier,
                     min_signed_long,
                     constant_identifier,
