@@ -94,6 +94,8 @@ class PythonModuleMixin:
             if Utils.python_version >= 330 and not package_filename:
                 return []
 
+            assert package_filename is not None, self.package_name
+
             imported_module, is_added = Recursion.recurseTo(
                 module_package  = package_package,
                 module_filename = package_filename,
@@ -122,7 +124,7 @@ class PythonModuleMixin:
         return None
 
     def getCompileTimeFilename(self):
-        return self.getSourceReference().getFilename()
+        return Utils.abspath(self.getSourceReference().getFilename())
 
     def getRunTimeFilename(self):
         reference_mode = Options.getFileReferenceMode()
@@ -347,8 +349,6 @@ class PythonModule(PythonModuleMixin, ChildrenHavingMixin,
             if result is not module_body:
                 self.setBody(result)
 
-        self.constraint_collection.makeVariableTraceOptimizations(self)
-
         new_modules = self.attemptRecursion()
 
         for new_module in new_modules:
@@ -505,7 +505,7 @@ class ExpressionModuleFileAttributeRef(NodeBase, ExpressionMixin):
                 source_ref = self.getSourceReference()
             )
 
-            return result, "new_expression", "Resolved to fixed __file__ value."
+            return result, "new_expression", "Using original '__file__' value."
 
         return self, None, None
 
