@@ -22,7 +22,6 @@ source code comments with developer manual sections.
 
 """
 
-from nuitka import Utils
 from nuitka.nodes.AssignNodes import (
     StatementAssignmentAttribute,
     StatementAssignmentSlice,
@@ -54,6 +53,8 @@ from nuitka.nodes.VariableRefNodes import (
     ExpressionTempVariableRef,
     ExpressionVariableRef
 )
+from nuitka.tree.SyntaxErrors import raiseSyntaxError
+from nuitka.utils import Utils
 
 from .Helpers import (
     buildNode,
@@ -300,6 +301,12 @@ def buildAssignmentStatementsFromDecoded(provider, kind, detail, source,
             final      = final_statements,
             source_ref = source_ref
         )
+    elif kind == "Starred":
+        raiseSyntaxError(
+            reason = "starred assignment target must be in a list or tuple",
+            source_ref = source_ref,
+            col_offset = 0
+        )
     else:
         assert False, (kind, source_ref, detail)
 
