@@ -17,7 +17,7 @@
 #     limitations under the License.
 #
 
-import os, sys, shutil, tempfile, time, difflib, subprocess
+import os, sys, shutil, time, difflib, subprocess
 
 # Find common code relative in file system. Not using packages for test stuff.
 sys.path.insert(
@@ -29,6 +29,7 @@ sys.path.insert(
         )
     )
 )
+
 from test_common import (
     my_print,
     setup,
@@ -122,6 +123,7 @@ def diffRecursive(dir1, dir2):
         if not os.path.exists(path1):
             sys.exit("Only in %s: %s" % (dir2, filename))
 
+
 def executePASS1():
     my_print("PASS 1: Compiling from compiler running from .py files.")
 
@@ -185,6 +187,7 @@ def executePASS1():
         nuitka_main_path,
         "--recurse-none",
         "--output-dir=.",
+        "--python-flag=-S",
         "nuitka.py"
     ]
     command += os.environ.get("NUITKA_EXTRA_OPTIONS", "").split()
@@ -222,6 +225,7 @@ def executePASS1():
         os.path.join("nuitka", "build", "include")
     )
 
+
 def compileAndCompareWith( nuitka ):
     base_dir = os.path.join("..", "..")
 
@@ -320,7 +324,7 @@ def executePASS3():
         nuitka_main_path,
         path,
         "--output-dir=%s" % tmp_dir,
-        "--exe",
+        "--python-flag=-S",
         "--recurse-all"
     ]
     result = subprocess.call(
